@@ -11,7 +11,14 @@
 #'
 #' The `vld_` function returns a flag indicating whether the test was met.
 #'
-#' @family chk_set
+#' @family set_checkers
+#'
+#' @seealso [vld_equivalent()]
+#' @seealso [unique()]
+#'
+#' @seealso For more details about the use of this function,
+#' please read the article
+#' `vignette("chk-families")`.
 #' @export
 #'
 #' @examples
@@ -39,6 +46,6 @@ chk_orderset <- function(x, values, x_name = NULL) {
 #' vld_orderset(1:2, 2:1)
 #' vld_orderset(1, 2:1)
 #' vld_orderset(1:2, 2)
-vld_orderset <- function(x, values)
+vld_orderset <- function(x, values) {
   vld_equivalent(unique(x[x %in% values]), values[values %in% x])
-
+}
