@@ -8,7 +8,12 @@
 #' @inheritParams params
 #' @inherit params return
 #'
-#' @family chk_is
+#' @family id_checkers
+#'
+#' @seealso [methods::is()]
+#' @seealso For more details about the use of this function,
+#' please read the article
+#' `vignette("chk-families")`.
 #'
 #' @examples
 #' # chk_s4_class
@@ -20,7 +25,8 @@ chk_s4_class <- function(x, class, x_name = NULL) {
     return(invisible(x))
   }
   if (is.null(x_name)) x_name <- deparse_backtick_chk(substitute(x))
-  abort_chk(x_name, " must inherit from S4 class '", class, "'", x = x, class = class)
+  .class <- class
+  abort_chk(x_name, " must inherit from S4 class '", .class, "'", x = x, .class = .class)
 }
 
 #' @describeIn chk_s4_class Validate Inherits from S4 Class
